@@ -1,5 +1,5 @@
 package WWW::FetchStory::Fetcher::AO3;
-$WWW::FetchStory::Fetcher::AO3::VERSION = '0.2004';
+$WWW::FetchStory::Fetcher::AO3::VERSION = '0.22';
 use strict;
 use warnings;
 =head1 NAME
@@ -8,7 +8,7 @@ WWW::FetchStory::Fetcher::AO3 - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.2004
+version 0.22
 
 =head1 DESCRIPTION
 
@@ -170,7 +170,7 @@ sub parse_chapter_urls {
 	@chapters = @{$args{urls}};
     }
     if (@chapters == 1
-	    and $content =~ m!href="(/downloads/[-\/\w]+/$sid/[^.]+\.html)!)
+	    and $content =~ m!href="(/downloads/$sid/[^.]+\.html)!)
     {
 	@chapters = ("http://archiveofourown.org$1");
     }
@@ -268,8 +268,18 @@ sub parse_summary {
     my $summary = '';
     if ($content =~ m!<h3[^>]*>Summary:</h3>\s*<blockquote class="userstuff"><p>([^<]+)</p></blockquote>!s)
     {
+        # This is a single-paragraph summary.
 	$summary = $1;
     }
+    elsif ($content =~ m!<h3[^>]*>Summary:</h3>\s*<blockquote class="userstuff">(.*?)</blockquote>!s)
+    {
+        # This is a multi-paragraph summary, it needs to be tidied up.
+	$summary = $1;
+        $summary =~ s!<p>!!g;
+        $summary =~ s!</p>!!g;
+        $summary =~ s/^\s*//;
+        $summary =~ s/\s*$//;
+    }
     else
     {
 	$summary = $self->SUPER::parse_summary(%args);
@@ -351,27 +361,16 @@ sub parse_universe {
     my $content = $args{content};
 
     my $universe = '';
-    if ($content =~ m!Fandom: &lt;a href=&quot;https?://archiveofourown\.org/tags/.*?&quot;&gt;(.*?)&lt;/a&gt!)
+    if ($content =~ m!<dd class="fandom tags">(.*?)</dd>!s)
     {
-        $universe = $1;
-    }
-    elsif ($content =~ m!^Fandom: (&lt;a href=&quot;https?://archiveofourown.org/tags/.*?,.*?)$!m)
-    {
-	my $fandoms = $1;
-	my @fds = split(/,/, $fandoms);
-	my @universes = ();
-	foreach my $fd (@fds)
-	{
-	    if ($fd =~ m!&lt;a href=&quot;https?://archiveofourown.org/tags/.*?&quot;&gt;(.*?)&lt;/a&gt;!m)
-	    {
-		push @universes, $1;
-	    }
-	}
-	$universe = join(', ', @universes);
-    }
-    elsif ($content =~ m!^Fandom: &lt;a href=&quot;https?://archiveofourown.org/tags/.*?&quot;&gt;(.*?)&lt;/a&gt;$!m)
-    {
-	$universe = $1;
+        # multiple fandoms inside links
+        my $str = $1;
+        my @univ = ();
+        while ($str =~ m!([^><]+)</a>!g)
+        {
+            push @univ, $1;
+        }
+        $universe = join(', ', @univ);
     }
     else
     {
@@ -390,6 +389,10 @@ sub parse_universe {
     {
         $universe = 'Blakes 7';
     }
+    elsif ($universe =~ m!(Marvel Cinematic Universe|Avengers|Iron Man)!)
+    {
+        $universe = 'MCU';
+    }
     return $universe;
 } # parse_universe
 
